<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>DeselectBlockReferences</name>
    <message>
        <location filename="../DeselectBlockReferencesInit.js" line="+2"/>
        <source>&amp;Deselect Block References</source>
        <translation>&amp;Blok Referans Seçimlerini Kaldır</translation>
    </message>
</context>
</TS>
